==> dl.php?src=linea21_1_8.zip: linea21/templates/admin/2015/login.php <==
<?php
/**
 * @package linea21\templates\admin
 * @author $Author$ - linea21 <info@linea21.com>
 * @version $Id$ 
 * @access public
 * @license http://opensource.org/licenses/gpl-3.0.html
 */
?>
<!doctype html>
<html xmlns="http://www.w3.org/1999/xhtml">
<head>
<title><?php echo _t('header','title'); ?></title>
<meta http-equiv="Content-Type"	content="text/html; charset=<?php echo CHARSET;?>" />
<link rel="shortcut icon" href="<?php echo THEME_ADMIN_PATH; ?>images/favicon.ico" />
<link rel="stylesheet" href="<?php echo THEME_ADMIN_PATH; ?>css/knacss.css" media="all" />
<link type="text/css" rel="StyleSheet" href="<?php echo THEME_ADMIN_PATH; ?>css/admin_common.css" />
<link type="text/css" rel="StyleSheet" href="<?php echo THEME_ADMIN_PATH; ?>css/admin_login.css" />
<script type="text/javascript" src="../lib/js/jquery.min.js"></script>
<script type="text/javascript">
$(document).ready(function() {
	$("#login").focus();
	$("#auth").hide().fadeIn(1500);
})
</script>
<?php if(isset($debugbar)) echo $debugbarRenderer->renderHead(); ?>
</head>
<body>
<?php culture::getInstance()->renderSwitcher(); ?>
<div id="content_auth">
	<h1 style="display: none;"><?php echo _t('divers','auth'); ?></h1>
	<div id="logo">
		<a href="http://www.linea21.com"><img src="<?php echo THEME_ADMIN_PATH; ?>images/menu_logo.png" alt="logo" /></a>
		<h2><?php echo SITE_NAME; ?> - <?php echo _t('admin', 'console')?></h2>
	</div>
	<div id="title">
		<p>
			<?php echo _t('divers','title_login'); ?>
		</p>
	</div>
	<div id="auth">
		<p class="error_auth">
			<?php
			if(isset($auth_res)) echo $auth_res;
			?>
		</p>
			<form action="<?php echo $_SERVER['PHP_SELF'];?>" method="post">
			<div id="formu">
				<div id="login_id"><input type="text" maxlength="20" class="loginfield" value="" name="login" id="login" /></div>
				<div id="login_pass"><input type="password" maxlength="100" class="loginfield" name="password" id="password" /></div>
				<?php
				if(defined('REMEMBER_ME') && REMEMBER_ME != 0) {
				?>
				<div id="login_rememberme"><input type="checkbox" name="rememberme" id="rememberme" /><label for="rememberme" class="autowidth"><?php echo _t('auth','rememberme') ?></label></div>
				<?php
				}
				?>
				<input type="submit" value="<?php echo _t('divers','auth'); ?>" name="valid" id="valid"  />
				<input type="hidden" name="page" id="page" value="<?php echo $page; ?>" />
			</div>
			</form>
		</div>
		<p class="cookie-message">
			<?php echo _t('divers','auth_mess1'); ?>
		</p>
	</div>
	<?php if(isset($debugbar)) echo $debugbarRenderer->render(); ?>
</body>
</html>

==> dl.php?src=linea21_2_0_0.zip: linea21/templates/admin/2015/login.php <==
<?php
/**
 * @package linea21\templates\admin
 * @author $Author$ - linea21 <info@linea21.com>
 * @version $Id$ 
 * @access public
 * @license http://opensource.org/licenses/gpl-3.0.html
 */
?>
<!doctype html>
<html xmlns="http://www.w3.org/1999/xhtml">
<head>
<title><?php echo _t('header','title'); ?></title>
<meta http-equiv="Content-Type"	content="text/html; charset=<?php echo CHARSET;?>" />
<link rel="shortcut icon" href="<?php echo THEME_ADMIN_PATH; ?>images/favicon.ico" />
<link rel="stylesheet" href="<?php echo THEME_ADMIN_PATH; ?>css/knacss.css" media="all" />
<link type="text/css" rel="StyleSheet" href="<?php echo THEME_ADMIN_PATH; ?>css/admin_common.css" />
<link type="text/css" rel="StyleSheet" href="<?php echo THEME_ADMIN_PATH; ?>css/admin_login.css" />
<script type="text/javascript" src="../lib/js/jquery-1.11.3.min.js"></script>
<script type="text/javascript" src="../lib/js/jquery-browser.js"></script>
<script type="text/javascript">
$(document).ready(function() {
	$("#login").focus();
	$("#auth").hide().fadeIn(1500);
})
</script>
<?php if(isset($debugbar)) echo $debugbarRenderer->renderHead(); ?>
</head>
<body>
<?php culture::getInstance()->renderSwitcher(); ?>
<div id="content_auth">
	<h1 style="display: none;"><?php echo _t('divers','auth'); ?></h1>
	<div id="logo">
		<a href="http://www.linea21.com"><img src="<?php echo THEME_ADMIN_PATH; ?>images/menu_logo.png" alt="logo" /></a>
		<h2><?php echo SITE_NAME; ?> - <?php echo _t('admin', 'console')?></h2>
	</div>
	<div id="title">
		<p>
			<?php echo _t('divers','title_login'); ?>
		</p>
	</div>
	<div id="auth">
		<p class="error_auth">
			<?php
			if(isset($auth_res)) echo $auth_res;
			?>
		</p>
			<form action="<?php echo $_SERVER['PHP_SELF'];?>" method="post">
			<div id="formu">
				<div id="login_id"><input type="text" maxlength="20" class="loginfield" value="" name="login" id="login" /></div>
				<div id="login_pass"><input type="password" maxlength="100" class="loginfield" name="password" id="password" /></div>
				<?php
				if(defined('REMEMBER_ME') && REMEMBER_ME != 0) {
				?>
				<div id="login_rememberme"><input type="checkbox" name="rememberme" id="rememberme" /><label for="rememberme" class="autowidth"><?php echo _t('auth','rememberme') ?></label></div>
				<?php
				}
				?>
				<input type="submit" value="<?php echo _t('divers','auth'); ?>" name="valid" id="valid"  />
				<input type="hidden" name="page" id="page" value="<?php echo $page; ?>" />
			</div>
			</form>
		</div>
		<p class="cookie-message">
			<?php echo _t('divers','auth_mess1'); ?>
		</p>
	</div>
	<?php if(isset($debugbar)) echo $debugbarRenderer->render(); ?>
</body>
</html>
